<template>
  <div>
    <div v-loading="statisticLoading">
      <el-row :gutter="20">
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">底价合计</div>
            <div class="statistic-num">{{ statistic.orderPartnerPriceAmount || 0 }}</div>
          </el-card>
        </el-col>
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">合伙人加价</div>
            <div class="statistic-num">
              {{ statistic.orderMarkupPartnerAmount || 0 }}
            </div>
          </el-card>
        </el-col>
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">会员折扣合计</div>
            <div class="statistic-num">
              {{ statistic.orderPriceDiscountAmount || 0 }}
            </div>
          </el-card>
        </el-col>
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">总销售扎数</div>
            <div class="statistic-num">
              {{ statistic.orderNum || 0 }}
            </div>
          </el-card>
        </el-col>
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">实际销售扎数</div>
            <div class="statistic-num">
              {{ statistic.realSaleNum || 0 }}
            </div>
          </el-card>
        </el-col>
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">缺货扎数</div>
            <div class="statistic-num">{{ statistic.orderLackNum || 0 }}</div>
          </el-card>
        </el-col>
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">降级扎数</div>
            <div class="statistic-num">{{ statistic.orderReduceNum || 0 }}</div>
          </el-card>
        </el-col>
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">补货扎数</div>
            <div class="statistic-num">{{ statistic.orderReplaceNum || 0 }}</div>
          </el-card>
        </el-col>
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">售后扣款合计</div>
            <div class="statistic-num">
              {{ statistic.orderFeePartner || 0 }}
            </div>
          </el-card>
        </el-col>
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">优惠券合计</div>
            <div class="statistic-num">{{ statistic.orderCouponAmountTotal || 0 }}</div>
          </el-card>
        </el-col>
        <el-col :span="4" class="mb-10">
          <el-card>
            <div class="statistic-title">包干费合计</div>
            <div class="statistic-num">
              {{ statistic.partnerTotalFeeAmount || 0 }}
            </div>
          </el-card>
        </el-col>
      </el-row>
    </div>
    <el-bus-crud v-bind="tableConfig" />
  </div>
</template>

<script>
import dayjs from 'dayjs'
import 'dayjs/locale/zh-cn'
import { getPartnerListNameWithIdConfig } from '@/utils/form-item-config'
dayjs.locale('zh-cn')
export default {
  data() {
    const paymentDateStart = `${dayjs().format('YYYY-MM-DD')}`
    const paymentDateEnd = `${dayjs().format('YYYY-MM-DD')}`
    return {
      statistic: {},
      statisticLoading: false,
      tableConfig: {
        url: 'flower/v2/report/order/partner/sale/page',
        hasNew: false,
        hasEdit: false,
        hasDelete: false,
        // viewText: '明细',
        hasExport: true,
        hasOperation: false,
        exportUrl: 'flower/v2/report/order/partner/sale/export',
        exportText: '导出',
        onResetView: (row) => {
          const url = this.$router.resolve(
            `/report/finance/${row.orderDate}`
          ).href
          window.open(url, '_blank')
        },
        operationAttrs: {
          width: 80,
          fixed: 'right',
        },
        beforeRequest: async (params) => {
          this.statisticLoading = true
          // eslint-disable-next-line
          let { code, data } = await this.$elBusHttp.request(
            `flower/v2/report/order/partner/sale/statis`,
            { params }
          )
          if (code === 0) {
            data = data || {}
            data.checkTotalFee = Number(
              (
                (data.orderCheckFee ?? 0) +
                (data.orderLackFeeSupplier ?? 0) +
                (data.orderReplaceFee ?? 0)
              ).toFixed(2)
            )
            data.saleTotalFee = Number(
              (
                (data.orderFeePartner ?? 0) +
                (data.orderFeeSupplier ?? 0) +
                (data.orderFeePlatform ?? 0)
              ).toFixed(2)
            )
            data.discountTotalFee = Number(
              (
                (data.orderPriceDiscountAmount ?? 0) +
                (data.orderCouponAmountTotal ?? 0)
              ).toFixed(2)
            )
            this.statistic = data || {}
          }
          this.statisticLoading = false
        },
        columns: [
          {
            label: '下单日期',
            prop: 'orderDate',
            minWidth: 120,
            fixed: 'left',
          },
          { label: '合伙人ID', prop: 'partnerId', minWidth: 120 },
          {
            label: '合伙人',
            prop: 'partnerName',
            minWidth: 120,
          },
          {
            label: '底价',
            prop: 'orderPartnerPriceAmount',
            minWidth: 120,
          },
          {
            label: '合伙人加价',
            prop: 'orderMarkupPartnerAmount',
            minWidth: 120,
          },
          {
            label: '会员折扣',
            prop: 'orderPriceDiscountAmount',
            minWidth: 120,
          },
          { label: '优惠券', prop: 'orderCouponAmountTotal', minWidth: 120 },
          { label: '售后扣合伙人款', prop: 'orderFeePartner', minWidth: 120 },

          { label: '总包干费', prop: 'partnerTotalFeeAmount', minWidth: 120 },

          { label: '总售扎数', prop: 'orderNum', minWidth: 120 },
          { label: '实际销售扎数', prop: 'realSaleNum', minWidth: 120 },
          { label: '缺货扎数', prop: 'orderLackNum', minWidth: 120 },
          { label: '降级扎数', prop: 'orderReduceNum', minWidth: 120 },
          { label: '补货扎数', prop: 'orderReplaceNum', minWidth: 120 },

          // { label: '实际销售扎数', prop: 'realSaleNum', minWidth: 120 },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              {
                label: '下单日期',
                id: 'paymentDateStart',
                component: 'el-bus-date-range',
                el: {
                  clearable: false,
                },
                // commonFormat: true,
                // commonFormatProps: ['paymentDateStart', 'paymentDateEnd'],
                inputFormat: (row) => {
                  if ('paymentDateStart' in row || 'paymentDateEnd' in row) {
                    return [
                      this.$elBusUtil.toDate(row.paymentDateStart),
                      this.$elBusUtil.toDate(row.paymentDateEnd),
                    ]
                  }
                },
                outputFormat: (val) => {
                  return {
                    paymentDateStart: `${this.$elBusUtil.toDate(val[0])}`,
                    paymentDateEnd: `${this.$elBusUtil.toDate(val[1])}`,
                  }
                },
                customClass: 'in-bus-form',
                commonRules: true,
                default: [paymentDateStart, paymentDateEnd],
              },
              { ...getPartnerListNameWithIdConfig(), label: '合伙人' },
            ],
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '财务报表',
    }
  },
}
</script>

<style lang="scss" scoped>
.statistic-title {
  text-align: center;
  font-size: 20px;
  color: $main-title-color;
  font-weight: bold;
  margin-bottom: 6px;
}
.statistic-num {
  text-align: center;
  font-size: 16px;
  color: $primary-color;
}
</style>
